@@ -13,13 +13,13 @@ use chrono::{DateTime, FixedOffset, Local};
 use clap::AppSettings;
 use structopt::StructOpt;
 
-use crate::files::FileLen;
+use crate::file::FileLen;
+use crate::group::FileGroupFilter;
+use crate::group::Replication::{Overreplicated, Underreplicated};
 use crate::path::Path;
 use crate::pattern::{Pattern, PatternError, PatternOpts};
 use crate::selector::PathSelector;
 use crate::transform::Transform;
-use crate::FileGroupFilter;
-use crate::Replication::{Overreplicated, Underreplicated};
 
 #[derive(Debug, Clone, Copy)]
 pub enum OutputFormat {
@@ -235,14 +235,23 @@ pub struct GroupConfig {
     #[structopt(long = "exclude", value_name("pattern"))]
     pub exclude_patterns: Vec<String>,
 
-    /// Makes pattern matching case-insensitive
+    /// Makes pattern matching case-insensitive.
     #[structopt(short = "i", long)]
     pub caseless: bool,
 
-    /// Expects patterns as Perl compatible regular expressions instead of Unix globs
+    /// Expects patterns as Perl compatible regular expressions instead of Unix globs.
     #[structopt(short = "g", long)]
     pub regex: bool,
 
+    /// Enables caching of file hashes.
+    ///
+    /// Caching can significantly speed up subsequent runs of `fclones group` by avoiding
+    /// recomputations of hashes of the files that haven't changed since the last scan.
+    /// Beware though, that this option relies on file modification times recorded by the
+    /// file system. It also increases memory and storage space consumption.
+    #[structopt(long)]
+    pub cache: bool,
+
     /// Sets the sizes of thread-pools
     ///
     /// The spec has the following format: `[<name>:]<r>[,<s>]`.
@@ -268,7 +277,7 @@ pub struct GroupConfig {
 
     /// Base directory to use when resolving relative input paths.
     #[structopt(long, parse(from_os_str), default_value("."))]
-    pub base_dir: PathBuf,
+    pub base_dir: Path,
 
     /// A list of input paths.
     ///
@@ -393,28 +402,25 @@ impl GroupConfig {
 
     /// Makes the base directory absolute.
     /// Returns error if the base directory does not exist.
-    pub fn resolve_base_dir(&mut self) -> io::Result<&PathBuf> {
+    pub fn resolve_base_dir(&mut self) -> io::Result<&Path> {
         if self.base_dir.is_relative() {
-            self.base_dir = std::env::current_dir()?.join(&self.base_dir)
+            let curr_dir = Arc::from(Path::from(std::env::current_dir()?));
+            self.base_dir = curr_dir.join(&self.base_dir)
         }
-        if !self.base_dir.is_dir() {
+        if !self.base_dir.to_path_buf().is_dir() {
             return Err(io::Error::new(
                 ErrorKind::NotFound,
-                format!("Directory not found: {}", self.base_dir.display()),
+                format!("Directory not found: {}", self.base_dir.to_escaped_string()),
             ));
         }
-        self.base_dir = self.base_dir.canonicalize()?;
+        self.base_dir = self.base_dir.canonicalize();
         Ok(&self.base_dir)
     }
 
     /// Returns an iterator over the absolute input paths.
     /// Input paths may be provided as arguments or from standard input.
     pub fn input_paths(&self) -> Box<dyn Iterator<Item = Path> + Send> {
-        let base_dir = Arc::new(if self.base_dir.as_os_str().is_empty() {
-            Path::from(".")
-        } else {
-            Path::from(&self.base_dir)
-        });
+        let base_dir = Arc::new(self.base_dir.clone());
         if self.stdin {
             Box::new(
                 BufReader::new(stdin())
